@@ -49,10 +49,12 @@
 
 package com.openexchange.imap;
 
-import java.io.IOException;
 import java.net.SocketTimeoutException;
+import static com.openexchange.mail.MailServletInterface.mailInterfaceMonitor;
 import java.nio.charset.UnsupportedCharsetException;
 import java.util.Arrays;
+import java.util.Collections;
+import java.util.Date;
 import java.util.Iterator;
 import java.util.Locale;
 import java.util.Map;
@@ -62,6 +64,7 @@ import java.util.Set;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicLong;
+import java.util.concurrent.locks.Lock;
 import javax.mail.AuthenticationFailedException;
 import javax.mail.MessagingException;
 import javax.mail.Provider;
@@ -96,6 +99,9 @@ import com.openexchange.imap.storecache.IMAPStoreContainer;
 import com.openexchange.java.Charsets;
 import com.openexchange.java.Strings;
 import com.openexchange.log.LogProperties;
+import com.openexchange.log.audit.AuditLogService;
+import com.openexchange.log.audit.DefaultAttribute;
+import com.openexchange.log.audit.DefaultAttribute.Name;
 import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.Protocol;
 import com.openexchange.mail.api.IMailFolderStorage;
@@ -109,14 +115,18 @@ import com.openexchange.mail.cache.IMailAccessCache;
 import com.openexchange.mail.config.MailProperties;
 import com.openexchange.mail.dataobjects.MailFolder;
 import com.openexchange.mail.mime.MimeMailException;
+import com.openexchange.mail.mime.MimeMailExceptionCode;
 import com.openexchange.mail.mime.MimeSessionPropertyNames;
 import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountStorageService;
 import com.openexchange.session.Session;
+import com.openexchange.session.Sessions;
 import com.openexchange.timer.ScheduledTimerTask;
 import com.openexchange.timer.TimerService;
 import com.openexchange.tools.ssl.TrustAllSSLSocketFactory;
 import com.sun.mail.iap.ConnectQuotaExceededException;
+import com.sun.mail.iap.StarttlsRequiredException;
+import com.sun.mail.imap.GreetingListener;
 import com.sun.mail.imap.IMAPFolder;
 import com.sun.mail.imap.IMAPStore;
 import com.sun.mail.imap.JavaIMAPStore;
@@ -172,7 +182,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
      */
     private static volatile ScheduledTimerTask cleanUpTimerTask;
 
-    private static Boolean checkConnectivityIfPolled;
+    private static volatile Boolean checkConnectivityIfPolled;
     private static boolean checkConnectivityIfPolled() {
         Boolean b = checkConnectivityIfPolled;
         if (null == b) {
@@ -192,6 +202,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         return b.booleanValue();
     }
 
+
     /*-
      * Member section
      */
@@ -443,7 +454,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                     final IMAPStoreCache imapStoreCache = IMAPStoreCache.getInstance();
                     if (null == imapStoreCache) {
                         closeSafely(imapStore);
-                    } else if (imapStore.isConnected()) {
+                    } else if (imapStore.isConnectedUnsafe()) {
                         imapStoreCache.returnIMAPStore(imapStore, accountId, server, port, login, session);
                     } else {
                         // Not null AND not connected...?
@@ -564,14 +575,8 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
              * Try to connect to IMAP server
              */
             final IIMAPProperties imapConfProps = (IIMAPProperties) config.getMailProperties();
-            String tmpPass = getMailConfig().getPassword();
-            if (tmpPass != null) {
-                try {
-                    tmpPass = new String(tmpPass.getBytes(Charsets.forName(imapConfProps.getImapAuthEnc())), Charsets.ISO_8859_1);
-                } catch (final UnsupportedCharsetException e) {
-                    LOG.error("", e);
-                }
-            }
+            String tmpPass = authEncode(getMailConfig().getPassword(), imapConfProps.getImapAuthEnc());
+            String login = authEncode(config.getLogin(), imapConfProps.getImapAuthEnc());
             /*
              * Get properties
              */
@@ -584,7 +589,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
              */
             javax.mail.Session imapSession;
             {
-                boolean forceSecure = imapConfig.isRequireTls() || imapConfProps.isEnforceSecureConnection();
+                boolean forceSecure = imapConfig.isStartTls() || imapConfig.isRequireTls() || imapConfProps.isEnforceSecureConnection();
                 imapSession = setConnectProperties(config, imapConfProps.getImapTimeout(), imapConfProps.getImapConnectionTimeout(), imapProps, JavaIMAPStore.class, forceSecure);
             }
             /*
@@ -601,7 +606,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                 /*
                  * Get connected store
                  */
-                imapStore = newConnectedImapStore(imapSession, IDNA.toASCII(config.getServer()), config.getPort(), config.getLogin(), tmpPass, -1, preAuthStartTlsCap);
+                imapStore = newConnectedImapStore(imapSession, IDNA.toASCII(config.getServer()), config.getPort(), login, tmpPass, -1, preAuthStartTlsCap, true);
                 /*
                  * Add warning if non-secure
                  */
@@ -629,6 +634,10 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                     OXException oxe = MimeMailException.handleMessagingException(e, config, session);
                     warnings.add(oxe);
                     throw oxe;
+                } else if (StarttlsRequiredException.class.isInstance(cause)) {
+                    OXException oxe = MailExceptionCode.NON_SECURE_DENIED.create(config.getServer());
+                    warnings.add(oxe);
+                    throw oxe;
                 }
                 warnings.add(MailExceptionCode.PING_FAILED.create(e, config.getServer(), config.getLogin(), e.getMessage()));
                 throw MimeMailException.handleMessagingException(e, config, session);
@@ -665,40 +674,30 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                  */
                 checkTemporaryDown(imapConfProps);
             }
-            String tmpPass = config.getPassword();
-            if (tmpPass != null) {
-                try {
-                    tmpPass = new String(tmpPass.getBytes(Charsets.forName(imapConfProps.getImapAuthEnc())), Charsets.ISO_8859_1);
-                } catch (final UnsupportedCharsetException e) {
-                    LOG.error("", e);
-                }
-            }
+            String encodedPassword = authEncode(config.getPassword(), imapConfProps.getImapAuthEnc());
             boolean certainPassword = false;
             if (certainPassword) {
-                tmpPass = "secret";
+                encodedPassword = "secret";
             }
-            final String proxyDelimiter = MailAccount.DEFAULT_ID == accountId ? MailProperties.getInstance().getAuthProxyDelimiter() : null;
             /*
              * Check for already failed authentication
              */
-            String login;
-            try {
-                login = new String(config.getLogin().getBytes(Charsets.forName(imapConfProps.getImapAuthEnc())), Charsets.ISO_8859_1);
-            } catch (final UnsupportedCharsetException e) {
-                LOG.error("", e);
-                login = config.getLogin();
-            }
-            String user = login;
+            String user = config.getLogin();
             String proxyUser = null;
             boolean isProxyAuth = false;
-            if (proxyDelimiter != null) {
-                final int pos = login.indexOf(proxyDelimiter);
-                if (pos >= 0) {
-                    isProxyAuth = true;
-                    proxyUser = login.substring(0, pos);
-                    user = login.substring(pos + proxyDelimiter.length());
+            {
+                String proxyDelimiter = MailAccount.DEFAULT_ID == accountId ? MailProperties.getInstance().getAuthProxyDelimiter() : null;
+                if (proxyDelimiter != null) {
+                    int pos = user.indexOf(proxyDelimiter);
+                    if (pos >= 0) {
+                        isProxyAuth = true;
+                        proxyUser = user.substring(0, pos);
+                        user = user.substring(pos + proxyDelimiter.length());
+                    }
                 }
             }
+            user = authEncode(user, imapConfProps.getImapAuthEnc());
+            proxyUser = authEncode(proxyUser, imapConfProps.getImapAuthEnc());
             /*
              * Get properties
              */
@@ -725,7 +724,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
              */
             {
                 final Class<? extends IMAPStore> clazz = useIMAPStoreCache() ? IMAPStoreCache.getInstance().getStoreClass() : JavaIMAPStore.class;
-                boolean forceSecure = accountId > 0 && (imapConfig.isRequireTls() || imapConfProps.isEnforceSecureConnection());
+                boolean forceSecure = accountId > 0 && (imapConfig.isStartTls() || imapConfig.isRequireTls() || imapConfProps.isEnforceSecureConnection());
                 imapSession = setConnectProperties(config, imapConfProps.getImapTimeout(), imapConfProps.getImapConnectionTimeout(), imapProps, clazz, forceSecure);
             }
             /*
@@ -752,7 +751,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             this.server = IDNA.toASCII(config.getServer());
             this.port = config.getPort();
             this.login = isProxyAuth ? proxyUser : user;
-            this.password = tmpPass;
+            this.password = encodedPassword;
             this.clientIp = clientIp;
             maxCount = getMaxCount();
             try {
@@ -775,6 +774,12 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                         }
                     }
                 }
+                {
+                    Exception next = e.getNextException();
+                    if (StarttlsRequiredException.class.isInstance(next)) {
+                        throw MailExceptionCode.NON_SECURE_DENIED.create(server);
+                    }
+                }
                 throw e;
             }
             this.connected = true;
@@ -799,21 +804,31 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
              * Special check for ACLs
              */
             if (config.isSupportsACLs()) {
-                final String key = new StringBuilder(server).append('@').append(port).toString();
+                String key = new StringBuilder(server).append('@').append(port).toString();
+                ConcurrentMap<String, Boolean> aclCapableServers = IMAPAccess.aclCapableServers;
                 Boolean b = aclCapableServers.get(key);
                 if (null == b) {
-                    Boolean nb;
-                    final IMAPFolder dummy = (IMAPFolder) imapStore.getFolder("INBOX");
+                    Lock lock = Sessions.optLock(session);
+                    lock.lock();
                     try {
-                        dummy.myRights();
-                        nb = Boolean.TRUE;
-                    } catch (MessagingException e) {
-                        // MessagingException - If the server doesn't support the ACL extension
-                        nb = Boolean.FALSE;
-                    }
-                    b = aclCapableServers.putIfAbsent(key, nb);
-                    if (null == b) {
-                        b = nb;
+                        b = aclCapableServers.get(key);
+                        if (null == b) {
+                            Boolean nb;
+                            IMAPFolder dummy = (IMAPFolder) imapStore.getFolder("INBOX");
+                            try {
+                                dummy.myRights();
+                                nb = Boolean.TRUE;
+                            } catch (MessagingException e) {
+                                // MessagingException - If the server doesn't support the ACL extension
+                                nb = Boolean.FALSE;
+                            }
+                            b = aclCapableServers.putIfAbsent(key, nb);
+                            if (null == b) {
+                                b = nb;
+                            }
+                        }
+                    } finally {
+                        lock.unlock();
                     }
                 }
                 if (!b.booleanValue()) {
@@ -880,6 +895,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             imapSession.getProperties().put("mail.imap.propagate.clientipaddress", clientIp);
         }
         imapSession.getProperties().put("mail.imap.failOnNOFetch", "true");
+
         /*
          * Cache failed authentication attempts
          */
@@ -892,7 +908,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
          */
         LogProperties.put(LogProperties.Name.MAIL_ACCOUNT_ID, Integer.valueOf(accountId));
         LogProperties.put(LogProperties.Name.MAIL_HOST, server + ":" + port);
-        LogProperties.put(LogProperties.Name.MAIL_LOGIN, login);
+        LogProperties.put(LogProperties.Name.MAIL_LOGIN, imapConfig.getLogin());
         /*-
          * Get connected IMAP store
          *
@@ -940,14 +956,14 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                 }
             }
         }
-        throw new MessagingException("Unable to connect to IMAP store: " + new URLName("imap", server, port, null, login, "xxxx"));
+        throw new MessagingException("Unable to connect to IMAP store: " + new URLName("imap", server, port, null, imapConfig.getLogin(), "xxxx"));
     }
 
     private IMAPStore newConnectedImapStore(javax.mail.Session imapSession, String server, int port, String login, String pw, int accountId) throws MessagingException {
-        return newConnectedImapStore(imapSession, server, port, login, pw, accountId, null);
+        return newConnectedImapStore(imapSession, server, port, login, pw, accountId, null, false);
     }
 
-    private IMAPStore newConnectedImapStore(javax.mail.Session imapSession, String server, int port, String login, String pw, int accountId, boolean[] preAuthStartTlsCap) throws MessagingException {
+    private IMAPStore newConnectedImapStore(javax.mail.Session imapSession, String server, int port, String login, String pw, int accountId, boolean[] preAuthStartTlsCap, boolean knownExternal) throws MessagingException {
         /*
          * Establish a new one...
          */
@@ -970,14 +986,14 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                     // Ignore
                 }
             }
-            doIMAPConnect(imapSession, imapStore, server, port, login, pw);
+            doIMAPConnect(imapSession, imapStore, server, port, login, pw, accountId, session, knownExternal);
         } catch (final AuthenticationFailedException e) {
             /*
              * Retry connect with AUTH=PLAIN disabled
              */
             imapSession.getProperties().put("mail.imap.auth.login.disable", "true");
             imapStore = (IMAPStore) imapSession.getStore(PROTOCOL);
-            doIMAPConnect(imapSession, imapStore, server, port, login, pw);
+            doIMAPConnect(imapSession, imapStore, server, port, login, pw, accountId, session, knownExternal);
         }
 
         String sessionInformation = imapStore.getClientParameter(IMAPClientParameters.SESSION_ID.getParamName());
@@ -994,15 +1010,19 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
      * the IMAP session, this Kerberos subject object is used to only allow a single IMAP login per Kerberos subject. The service ticket for
      * the IMAP server is stored in the Kerberos subject once the IMAP login was successful. If multiple threads can execute this in
      * parallel, multiple IMAP service tickets are requested, which is discouraged for performance reasons.
+     *
      * @param imapSession The IMAP session
      * @param imapStore The IMAP store
      * @param server The host name
      * @param port The port
      * @param login The login
      * @param pw The password
+     * @param accountId The account identifier
+     * @param session The associated Groupware session
+     * @param knownExternal <code>true</code> if it is known that a connection is supposed to be established to an external IMAP service, otherwise <code>false</code> if not known
      * @throws MessagingException If operation fails
      */
-    public static void doIMAPConnect(javax.mail.Session imapSession, IMAPStore imapStore, String server, int port, String login, String pw) throws MessagingException {
+    public static void doIMAPConnect(javax.mail.Session imapSession, IMAPStore imapStore, String server, int port, String login, String pw, int accountId, Session session, boolean knownExternal) throws MessagingException {
         Object kerberosSubject = imapSession.getProperties().get("mail.imap.sasl.kerberosSubject");
         if (null == kerberosSubject) {
             imapStore.connect(server, port, login, pw);
@@ -1011,26 +1031,33 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                 imapStore.connect(server, port, login, pw);
             }
         }
+
+        AuditLogService auditLogService = Services.optService(AuditLogService.class);
+        if (null != auditLogService) {
+            String eventId = knownExternal ? "imap.external.login" : (MailAccount.DEFAULT_ID == accountId ? "imap.primary.login" : "imap.external.login");
+            auditLogService.log(eventId, DefaultAttribute.valueFor(Name.LOGIN, session.getLoginName()), DefaultAttribute.valueFor(Name.IP_ADDRESS, session.getLocalIp()), DefaultAttribute.timestampFor(new Date()), DefaultAttribute.arbitraryFor("imap.login", login), DefaultAttribute.arbitraryFor("imap.server", server), DefaultAttribute.arbitraryFor("imap.port", Integer.toString(port)));
+        }
     }
 
     private IMAPStore borrowIMAPStore(javax.mail.Session imapSession, String server, int port, String login, String pw, boolean propagateClientIp, boolean checkConnectivityIfPolled) throws MessagingException, OXException {
         return IMAPStoreCache.getInstance().borrowIMAPStore(accountId, imapSession, server, port, login, pw, session, propagateClientIp, checkConnectivityIfPolled);
     }
 
-    private void checkTemporaryDown(final IIMAPProperties imapConfProps) throws OXException, IMAPException {
-        final MailConfig mailConfig = getMailConfig();
-        final HostAndPort key = new HostAndPort(mailConfig.getServer(), mailConfig.getPort());
-        final Map<HostAndPort, Long> map = timedOutServers;
+    private void checkTemporaryDown(IIMAPProperties imapConfProps) throws OXException, IMAPException {
+        Map<HostAndPort, Long> map = timedOutServers;
         if (null == map) {
             return;
         }
-        final Long range = map.get(key);
+
+        MailConfig mailConfig = getMailConfig();
+        HostAndPort key = new HostAndPort(mailConfig.getServer(), mailConfig.getPort());
+        Long range = map.get(key);
         if (range != null) {
             if (System.currentTimeMillis() - range.longValue() <= imapConfProps.getImapTemporaryDown()) {
                 /*
-                 * Still treated as being temporary broken
+                 * Still considered as being temporary broken
                  */
-                throw IMAPException.create(IMAPException.Code.CONNECT_ERROR, mailConfig.getServer(), mailConfig.getLogin());
+                throw MimeMailExceptionCode.CONNECT_ERROR.create(mailConfig.getServer(), mailConfig.getLogin()).markLightWeight();
             }
             map.remove(key);
         }
@@ -1128,7 +1155,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         RootSubfoldersEnabledCache.init();
         ACLExtensionInit.getInstance().start();
         Entity2ACLInit.getInstance().start();
-        maxCountCache = new NonBlockingHashMap<String, Integer>(16);
+        maxCountCache = new NonBlockingHashMap<>(16);
 
         final ConfigurationService confService = Services.getService(ConfigurationService.class);
         final boolean useIMAPStoreCache = null == confService ? true : confService.getBoolProperty("com.openexchange.imap.useIMAPStoreCache", true);
@@ -1144,10 +1171,10 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
 
     private static synchronized void initMaps() {
         if (null == timedOutServers) {
-            timedOutServers = new NonBlockingHashMap<HostAndPort, Long>();
+            timedOutServers = new NonBlockingHashMap<>();
         }
         if (null == aclCapableServers) {
-            aclCapableServers = new NonBlockingHashMap<String, Boolean>();
+            aclCapableServers = new NonBlockingHashMap<>();
         }
         if (null == cleanUpTimerTask) {
             final TimerService timerService = Services.getService(TimerService.class);
@@ -1281,6 +1308,29 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         if (connectionTimeout > 0) {
             imapProps.put("mail.imap.connectiontimeout", String.valueOf(connectionTimeout));
         }
+        /*
+         * Specify CLOSE behavior
+         */
+        imapProps.put("mail.imap.explicitCloseForReusedProtocol", "true");
+        /*
+         * Specify NOOP behavior
+         */
+        imapProps.put("mail.imap.issueNoopToKeepConnectionAlive", "false");
+        /*
+         * Enable/disable audit log
+         */
+        if (config.getIMAPProperties().isAuditLogEnabled()) {
+            imapProps.put("mail.imap.auditLog.enabled", "true");
+        }
+        /*
+         * Greeting listener (for primary IMAP)
+         */
+        if (config.getAccountId() == MailAccount.DEFAULT_ID) {
+            GreetingListener greetingListener = IMAPProperties.getInstance().getHostNameRegex();
+            if (null != greetingListener) {
+                imapProps.put("mail.imap.greeting.listeners", Collections.singletonList(greetingListener));
+            }
+        }
         /*
          * Check if a secure IMAP connection should be established
          */
@@ -1316,31 +1366,10 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             /*
              * Enables the use of the STARTTLS command (if supported by the server) to switch the connection to a TLS-protected connection.
              */
-            if (forceSecure || config.getIMAPProperties().isEnableTls()) {
-                try {
-                    final String serverUrl = new StringBuilder(36).append(IDNA.toASCII(config.getServer())).append(':').append(config.getPort()).toString();
-                    final Map<String, String> capabilities = IMAPCapabilityAndGreetingCache.getCapabilities(serverUrl, false, config.getIMAPProperties());
-                    if (null != capabilities) {
-                        if (capabilities.containsKey("STARTTLS")) {
-                            imapProps.put("mail.imap.starttls.enable", "true");
-                        } else if (forceSecure) {
-                            // No SSL demanded and IMAP server seems not to support TLS
-                            throw MailExceptionCode.NON_SECURE_DENIED.create(config.getServer());
-                        }
-                    } else {
-                        if (forceSecure) {
-                            // No SSL demanded and IMAP server seems not to support TLS
-                            throw MailExceptionCode.NON_SECURE_DENIED.create(config.getServer());
-                        }
-                        imapProps.put("mail.imap.starttls.enable", "true");
-                    }
-                } catch (final IOException e) {
-                    if (forceSecure) {
-                        // No SSL demanded and IMAP server seems not to support TLS
-                        throw MailExceptionCode.NON_SECURE_DENIED.create(e, config.getServer());
-                    }
-                    imapProps.put("mail.imap.starttls.enable", "true");
-                }
+            if (forceSecure) {
+                imapProps.put("mail.imap.starttls.required", "true");
+            } else if (config.getIMAPProperties().isEnableTls()) {
+                imapProps.put("mail.imap.starttls.enable", "true");
             }
             /*
              * Specify the javax.net.ssl.SSLSocketFactory class, this class will be used to create IMAP SSL sockets if TLS handshake says
@@ -1428,4 +1457,17 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         }
     }
 
+    private static String authEncode(String s, String charset) {
+        String tmp = s;
+        if (tmp != null) {
+            try {
+                tmp = new String(s.getBytes(Charsets.forName(charset)), Charsets.ISO_8859_1);
+            } catch (final UnsupportedCharsetException e) {
+                LOG.error("Unsupported encoding in a message detected and monitored", e);
+                mailInterfaceMonitor.addUnsupportedEncodingExceptions(e.getMessage());
+            }
+        }
+        return tmp;
+    }
+
 }
