@@ -375,7 +375,7 @@ public class IMAPDefaultFolderChecker {
                             ListLsubCache.addSingle(INBOX, accountId, inboxFolder, session, ignoreSubscription);
                             inboxListEntry = ListLsubCache.getCachedLISTEntry(INBOX, accountId, inboxFolder, session, ignoreSubscription);
                         }
-                        char sep = inboxFolder.getSeparator();
+                        char sep = inboxListEntry.getSeparator();
                         /*
                          * Get prefix for default folder names, NOT full names!
                          */
@@ -1321,7 +1321,7 @@ public class IMAPDefaultFolderChecker {
     }
 
     /** Gets fall-back name */
-    protected static String getFallbackName(int index) {
+    public static String getFallbackName(int index) {
         switch (index) {
         case StorageUtility.INDEX_CONFIRMED_HAM:
             return DefaultFolderNamesProvider.DEFAULT_PROVIDER.getConfirmedHam();
