@@ -71,6 +71,7 @@ import javax.mail.Message;
 import javax.mail.Message.RecipientType;
 import javax.mail.MessagingException;
 import javax.mail.Multipart;
+import javax.mail.Part;
 import javax.mail.UIDFolder;
 import javax.mail.internet.AddressException;
 import javax.mail.internet.InternetAddress;
@@ -80,11 +81,14 @@ import javax.mail.internet.ParameterList;
 import com.openexchange.exception.OXException;
 import com.openexchange.imap.IMAPServerInfo;
 import com.openexchange.java.Strings;
+import com.openexchange.log.LogProperties;
+import com.openexchange.mail.FullnameArgument;
 import com.openexchange.mail.dataobjects.IDMailMessage;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.mime.ContentType;
 import com.openexchange.mail.mime.MessageHeaders;
 import com.openexchange.mail.mime.MimeMailException;
+import com.openexchange.mail.mime.PlainTextAddress;
 import com.openexchange.mail.mime.QuotedInternetAddress;
 import com.openexchange.mail.mime.converters.MimeMessageConverter;
 import com.openexchange.mail.mime.utils.MimeMessageUtility;
@@ -121,7 +125,6 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
     private static final int LENGTH = 9; // "FETCH <nums> (<command>)"
     private static final int LENGTH_WITH_UID = 13; // "UID FETCH <nums> (<command>)"
 
-    private final char separator;
     private String[] args;
     private final String command;
     private boolean uid;
@@ -141,21 +144,19 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
      * Initializes a new {@link MailMessageFetchIMAPCommand}.
      *
      * @param imapFolder The IMAP folder providing connected protocol
-     * @param separator The separator character
      * @param isRev1 Whether IMAP server has <i>IMAP4rev1</i> capability or not
      * @param seqNums The sequence numbers to fetch
      * @param fp The fetch profile to use
      * @param serverInfo The IMAP server information deduced from configuration
      * @throws MessagingException If initialization fails
      */
-    public MailMessageFetchIMAPCommand(IMAPFolder imapFolder, char separator, boolean isRev1, int[] seqNums, FetchProfile fp, IMAPServerInfo serverInfo) throws MessagingException {
+    public MailMessageFetchIMAPCommand(IMAPFolder imapFolder, boolean isRev1, int[] seqNums, FetchProfile fp, IMAPServerInfo serverInfo) throws MessagingException {
         super(imapFolder);
         determineAttachmentByHeader = false;
         final int messageCount = imapFolder.getMessageCount();
         if (messageCount <= 0) {
             returnDefaultValue = true;
         }
-        this.separator = separator;
         lastHandlers = new HashSet<FetchItemHandler>();
         command = getFetchCommand(isRev1, fp, false, serverInfo);
         uid = false;
@@ -177,20 +178,18 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
      * Initializes a new {@link MailMessageFetchIMAPCommand} to fetch all messages.
      *
      * @param imapFolder The IMAP folder providing connected protocol
-     * @param separator The separator character
      * @param isRev1 Whether IMAP server has <i>IMAP4rev1</i> capability or not
      * @param fp The fetch profile to use
      * @param serverInfo The IMAP server information deduced from configuration
      * @throws MessagingException If initialization fails
      */
-    public MailMessageFetchIMAPCommand(IMAPFolder imapFolder, char separator, boolean isRev1, FetchProfile fp, IMAPServerInfo serverInfo) throws MessagingException {
+    public MailMessageFetchIMAPCommand(IMAPFolder imapFolder, boolean isRev1, FetchProfile fp, IMAPServerInfo serverInfo) throws MessagingException {
         super(imapFolder);
         determineAttachmentByHeader = false;
         final int messageCount = imapFolder.getMessageCount();
         if (messageCount <= 0) {
             returnDefaultValue = true;
         }
-        this.separator = separator;
         lastHandlers = new HashSet<FetchItemHandler>();
         command = getFetchCommand(isRev1, fp, false, serverInfo);
         uid = false;
@@ -209,21 +208,19 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
      * Initializes a new {@link MailMessageFetchIMAPCommand}.
      *
      * @param imapFolder The IMAP folder providing connected protocol
-     * @param separator The separator character
      * @param isRev1 Whether IMAP server has <i>IMAP4rev1</i> capability or not
      * @param uids The UIDs to fetch
      * @param fp The fetch profile to use
      * @param serverInfo The IMAP server information deduced from configuration
      * @throws MessagingException If initialization fails
      */
-    public MailMessageFetchIMAPCommand(IMAPFolder imapFolder, char separator, boolean isRev1, long[] uids, FetchProfile fp, IMAPServerInfo serverInfo) throws MessagingException {
+    public MailMessageFetchIMAPCommand(IMAPFolder imapFolder, boolean isRev1, long[] uids, FetchProfile fp, IMAPServerInfo serverInfo) throws MessagingException {
         super(imapFolder);
         determineAttachmentByHeader = false;
         final int messageCount = imapFolder.getMessageCount();
         if (messageCount <= 0) {
             returnDefaultValue = true;
         }
-        this.separator = separator;
         lastHandlers = new HashSet<FetchItemHandler>();
         length = uids.length;
         uid2index = new TLongIntHashMap(length, Constants.DEFAULT_LOAD_FACTOR, 0, -1);
@@ -450,7 +447,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
         boolean error = false;
         MailMessage mail;
         try {
-            mail = handleFetchRespone(fetchResponse, fullname, separator, lastHandlers, determineAttachmentByHeader, checkICal, checkVCard, treatEmbeddedAsAttachment);
+            mail = handleFetchRespone(fetchResponse, fullname, lastHandlers, determineAttachmentByHeader, checkICal, checkVCard, treatEmbeddedAsAttachment);
         } catch (final MessagingException e) {
             /*
              * Discard corrupt message
@@ -480,13 +477,12 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
      *
      * @param fetchResponse The FETCH response to handle
      * @param fullName The full name of associated folder
-     * @param separator The separator character
      * @return The resulting mail message
      * @throws MessagingException If a messaging error occurs
      * @throws OXException If an OX error occurs
      */
-    public static MailMessage handleFetchRespone(final FetchResponse fetchResponse, final String fullName, final char separator) throws MessagingException, OXException {
-        return handleFetchRespone(new IDMailMessage(null, fullName), fetchResponse, fullName, separator, null, false, false, false, false);
+    public static MailMessage handleFetchRespone(final FetchResponse fetchResponse, final String fullName) throws MessagingException, OXException {
+        return handleFetchRespone(new IDMailMessage(null, fullName), fetchResponse, fullName, null, false, false, false, false);
     }
 
     /**
@@ -495,20 +491,19 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
      * @param mail The message to apply to
      * @param fetchResponse The FETCH response to handle
      * @param fullName The full name of associated folder
-     * @param separator The separator character
      * @return The resulting mail message
      * @throws MessagingException If a messaging error occurs
      * @throws OXException If an OX error occurs
      */
-    public static MailMessage handleFetchRespone(final IDMailMessage mail, final FetchResponse fetchResponse, final String fullName, final char separator) throws MessagingException, OXException {
-        return handleFetchRespone(mail, fetchResponse, fullName, separator, null, false, false, false, false);
+    public static MailMessage handleFetchRespone(final IDMailMessage mail, final FetchResponse fetchResponse, final String fullName) throws MessagingException, OXException {
+        return handleFetchRespone(mail, fetchResponse, fullName, null, false, false, false, false);
     }
 
-    private static MailMessage handleFetchRespone(FetchResponse fetchResponse, String fullName, char separator, Set<FetchItemHandler> lastHandlers, boolean determineAttachmentByHeader, boolean checkICal, boolean checkVCard, boolean treatEmbeddedAsAttachment) throws MessagingException, OXException {
-        return handleFetchRespone(new IDMailMessage(null, fullName), fetchResponse, fullName, separator, lastHandlers, determineAttachmentByHeader, checkICal, checkVCard, treatEmbeddedAsAttachment);
+    private static MailMessage handleFetchRespone(FetchResponse fetchResponse, String fullName, Set<FetchItemHandler> lastHandlers, boolean determineAttachmentByHeader, boolean checkICal, boolean checkVCard, boolean treatEmbeddedAsAttachment) throws MessagingException, OXException {
+        return handleFetchRespone(new IDMailMessage(null, fullName), fetchResponse, fullName, lastHandlers, determineAttachmentByHeader, checkICal, checkVCard, treatEmbeddedAsAttachment);
     }
 
-    private static MailMessage handleFetchRespone(IDMailMessage mail, FetchResponse fetchResponse, String fullName, char separator, Set<FetchItemHandler> lastHandlers, boolean determineAttachmentByHeader, boolean checkICal, boolean checkVCard, boolean treatEmbeddedAsAttachment) throws MessagingException, OXException {
+    private static MailMessage handleFetchRespone(IDMailMessage mail, FetchResponse fetchResponse, String fullName, Set<FetchItemHandler> lastHandlers, boolean determineAttachmentByHeader, boolean checkICal, boolean checkVCard, boolean treatEmbeddedAsAttachment) throws MessagingException, OXException {
         final IDMailMessage m;
         if (null == mail) {
             m = new IDMailMessage(null, fullName);
@@ -517,9 +512,6 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
             m.setFolder(fullName);
         }
         // mail.setRecentCount(recentCount);
-        if (separator != '\0') {
-            m.setSeparator(separator);
-        }
         m.setSeqnum(fetchResponse.getNumber());
         final int itemCount = fetchResponse.getItemCount();
         final Map<Class<? extends Item>, FetchItemHandler> map = MAP;
@@ -549,6 +541,10 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
                 m.setHasAttachment(new ContentType(cts).startsWith("multipart/mixed"));
             }
         }
+
+        // Drop possible set "com.openexchange.mail.mailId" log property
+        LogProperties.remove(LogProperties.Name.MAIL_MAIL_ID);
+
         return m;
     }
 
@@ -930,11 +926,13 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
             int length = addresses.length;
             InternetAddress[] ret = new InternetAddress[length];
             for (int i = length; i-- > 0;) {
+                String sAddress = addresses[i].toString();
                 try {
-                    ret[i] = new QuotedInternetAddress(addresses[i].toString());
+                    ret[i] = new QuotedInternetAddress(sAddress, false);
                 } catch (AddressException e) {
                     // Use as-is
-                    ret[i] = addresses[i];
+                    String parsed = e.getRef();
+                    ret[i] = new PlainTextAddress(null == parsed ? sAddress : parsed);
                 }
             }
             return ret;
@@ -1029,7 +1027,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
             msg.setContentType(contentType);
             msg.addHeader("Content-Type", contentType.toString(true));
 
-            boolean hasAttachment = bs.isMulti() && (MULTI_SUBTYPE_MIXED.equalsIgnoreCase(bs.subtype) || MimeMessageUtility.hasAttachments(bs));
+            boolean hasAttachment = MimeMessageUtility.hasAttachments(bs);
             if (hasAttachment) {
                 if (checkICal && hasICal(bs)) {
                     msg.addHeader("X-ICAL", "true");
@@ -1115,9 +1113,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
             } else {
                 try {
                     final ContentType ct = new ContentType(contentType);
-                    msg.setHasAttachment(ct.startsWith("multipart/") && ("mixed".equalsIgnoreCase(ct.getSubType()) || MimeMessageUtility.hasAttachments(
-                        (Multipart) message.getContent(),
-                        ct.getSubType())));
+                    msg.setHasAttachment(MimeMessageUtility.hasAttachments((Part) message.getContent()));
                 } catch (final IOException e) {
                     throw new MessagingException(e.getMessage(), e);
                 }
@@ -1132,8 +1128,10 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
         @Override
         public void handleItem(final Item item, final IDMailMessage msg, final org.slf4j.Logger logger) {
             long id = ((UID) item).uid;
-            msg.setMailId(Long.toString(id));
+            String sUid = Long.toString(id);
+            msg.setMailId(sUid);
             msg.setUid(id);
+            LogProperties.put(LogProperties.Name.MAIL_MAIL_ID, sUid);
         }
 
         @Override
