@@ -91,7 +91,6 @@ public final class MailMessageFillerIMAPCommand extends AbstractIMAPCommand<Void
     private final boolean uid;
     private final String fullname;
     private final int index;
-    private final char separator;
 
     /**
      * Initializes a new {@link MailMessageFillerIMAPCommand}.
@@ -103,7 +102,6 @@ public final class MailMessageFillerIMAPCommand extends AbstractIMAPCommand<Void
             returnDefaultValue = true;
         }
         index = 0;
-        separator = imapFolder.getSeparator();
         length = messages.size();
         // Fill collection
         TLongObjectMap<MailMessage> tm = new TLongObjectHashMap<MailMessage>(length);
@@ -178,7 +176,7 @@ public final class MailMessageFillerIMAPCommand extends AbstractIMAPCommand<Void
             MailMessage message = messages.get(uid.uid);
             if (null != message) {
                 try {
-                    MailMessageFetchIMAPCommand.handleFetchRespone((IDMailMessage) message, fetchResponse, fullname, separator);
+                    MailMessageFetchIMAPCommand.handleFetchRespone((IDMailMessage) message, fetchResponse, fullname);
                 } catch (OXException e) {
                     /*
                      * Discard corrupt message
