@@ -55,9 +55,12 @@ import java.util.Collections;
 import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
+import java.util.regex.Pattern;
+import java.util.regex.PatternSyntaxException;
 import org.cliffc.high_scale_lib.NonBlockingHashMap;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
+import com.openexchange.imap.HostExtractingGreetingListener;
 import com.openexchange.imap.IMAPProtocol;
 import com.openexchange.imap.entity2acl.Entity2ACL;
 import com.openexchange.imap.services.Services;
@@ -135,6 +138,8 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
 
     private boolean enableTls;
 
+    private boolean auditLogEnabled;
+
     private Set<String> propagateHostNames;
 
     private boolean allowFolderCaches;
@@ -147,6 +152,8 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
 
     private String cipherSuites;
 
+    private HostExtractingGreetingListener hostExtractingGreetingListener;
+
     /**
      * Initializes a new {@link IMAPProperties}
      */
@@ -154,12 +161,14 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
         super();
         sContainerType = "boundary-aware";
         enableTls = true;
+        auditLogEnabled = false;
         maxNumConnection = -1;
         newACLExtMap = new NonBlockingHashMap<String, Boolean>();
         mailProperties = MailProperties.getInstance();
         propagateHostNames = Collections.emptySet();
         allowFetchSingleHeaders = true;
         allowFolderCaches = true;
+        hostExtractingGreetingListener = null;
     }
 
     @Override
@@ -234,6 +243,12 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
             logBuilder.append("\tEnable TLS: ").append(enableTls).append('\n');
         }
 
+        {
+            String tmp = configuration.getProperty("com.openexchange.imap.auditLog.enabled", STR_FALSE).trim();
+            auditLogEnabled = Boolean.parseBoolean(tmp);
+            logBuilder.append("\tAudit Log Enabled: ").append(auditLogEnabled).append('\n');
+        }
+
         {
             final String tmp = configuration.getProperty("com.openexchange.imap.propagateHostNames", "").trim();
             if (tmp.length() > 0) {
@@ -421,6 +436,20 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
             this.cipherSuites = Strings.isEmpty(tmp) ? null : tmp;
             logBuilder.append("\tSupported SSL cipher suites: ").append(null == this.cipherSuites ? "<default>" : cipherSuites).append("\n");
         }
+        
+        {
+            String tmp = configuration.getProperty("com.openexchange.imap.greeting.host.regex", "").trim();
+            tmp = Strings.isEmpty(tmp) ? null : tmp;
+            if (null != tmp) {
+                try {
+                    Pattern pattern = Pattern.compile(tmp);
+                    hostExtractingGreetingListener = new HostExtractingGreetingListener(pattern);
+                    logBuilder.append("\tHost name regular expression: ").append(tmp).append("\n");
+                } catch (PatternSyntaxException e) {
+                    logBuilder.append("\tHost name regular expression: Invalid value \"").append(null == tmp ? "<none>" : tmp).append("\". Using no host name extraction\n");
+                }
+            }
+        }
 
         logBuilder.append("Global IMAP properties successfully loaded!");
 
@@ -435,6 +464,7 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
         fastFetch = true;
         propagateClientIPAddress = false;
         enableTls = true;
+        auditLogEnabled = false;
         propagateHostNames = Collections.emptySet();
         supportsACLs = null;
         imapTimeout = 0;
@@ -452,6 +482,7 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
         notifyFullNames = "INBOX";
         sslProtocols = "SSLv3 TLSv1";
         cipherSuites = null;
+        hostExtractingGreetingListener = null;
     }
 
     @Override
@@ -484,6 +515,11 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
         return enableTls;
     }
 
+    @Override
+    public boolean isAuditLogEnabled() {
+        return auditLogEnabled;
+    }
+
     @Override
     public Set<String> getPropagateHostNames() {
         return propagateHostNames;
@@ -677,4 +713,13 @@ public final class IMAPProperties extends AbstractProtocolProperties implements
         return cipherSuites;
     }
 
+    /**
+     * Gets the greeting listener to parse the host name information from <b><i>primary</i></b> IMAP server's greeting string.
+     *
+     * @return The host name extractor or <code>null</code>
+     */
+    public HostExtractingGreetingListener getHostNameRegex() {
+        return hostExtractingGreetingListener;
+    }
+
 }
