@@ -62,6 +62,7 @@ import org.osgi.service.event.EventHandler;
 import com.openexchange.ajax.customizer.folder.AdditionalFolderField;
 import com.openexchange.caching.CacheService;
 import com.openexchange.caching.events.CacheEventService;
+import com.openexchange.charset.CharsetService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Reloadable;
 import com.openexchange.config.cascade.ConfigViewFactory;
@@ -78,11 +79,9 @@ import com.openexchange.imap.notify.internal.IMAPNotifierRegistry;
 import com.openexchange.imap.osgi.console.ListLsubCommandProvider;
 import com.openexchange.imap.services.Services;
 import com.openexchange.imap.storecache.IMAPStoreCache;
-import com.openexchange.imap.threader.ThreadableCache;
-import com.openexchange.imap.threader.ThreadableLoginHandler;
 import com.openexchange.imap.threader.references.ConversationCache;
 import com.openexchange.imap.util.ExtAccountFolderField;
-import com.openexchange.login.LoginHandlerService;
+import com.openexchange.log.audit.AuditLogService;
 import com.openexchange.mail.FullnameArgument;
 import com.openexchange.mail.api.MailProvider;
 import com.openexchange.mail.utils.MailFolderUtility;
@@ -125,7 +124,7 @@ public final class IMAPActivator extends HousekeepingActivator {
         return new Class<?>[] {
             ConfigurationService.class, CacheService.class, CacheEventService.class, UserService.class, MailAccountStorageService.class,
             ThreadPoolService.class, TimerService.class, SessiondService.class, DatabaseService.class, TextXtractService.class,
-            EventAdmin.class, GroupService.class, ContextService.class, ConfigViewFactory.class };
+            EventAdmin.class, GroupService.class, ContextService.class, ConfigViewFactory.class, CharsetService.class };
     }
 
     @Override
@@ -158,6 +157,7 @@ public final class IMAPActivator extends HousekeepingActivator {
             track(MailcapCommandMap.class, new MailcapServiceTracker(context));
             track(CacheEventService.class, new ListLsubInvalidator(context));
             trackService(FolderService.class);
+            trackService(AuditLogService.class);
             openTrackers();
             /*
              * Command provider
@@ -206,9 +206,8 @@ public final class IMAPActivator extends HousekeepingActivator {
                 ConversationCache.initInstance(this);
             }
             /*
-             * Register login handler
+             * Register reloadbale
              */
-            registerService(LoginHandlerService.class, new ThreadableLoginHandler(this));
             registerService(Reloadable.class, IMAPReloadable.getInstance());
             /*
              * Register event handler
@@ -254,7 +253,6 @@ public final class IMAPActivator extends HousekeepingActivator {
                             if (null != userId) {
                                 ListLsubCache.dropFor(userId.intValue(), contextId.intValue(), false);
                                 IMAPStoreCache.getInstance().dropFor(userId.intValue(), contextId.intValue());
-                                ThreadableCache.dropFor(userId.intValue(), contextId.intValue());
 
                                 IMAPNotifierRegistry.getInstance().handleRemovedSession(userId.intValue(), contextId.intValue());
                                 ConversationCache.getInstance().removeUserConversations(userId.intValue(), contextId.intValue());
@@ -277,7 +275,6 @@ public final class IMAPActivator extends HousekeepingActivator {
                         Session session = (Session) event.getProperty("com.openexchange.passwordchange.session");
                         ListLsubCache.dropFor(session);
                         IMAPStoreCache.getInstance().dropFor(userId, contextId);
-                        ThreadableCache.dropFor(session);
                     }
 
                 };
@@ -328,7 +325,6 @@ public final class IMAPActivator extends HousekeepingActivator {
              */
             ConversationCache.releaseInstance();
             IMAPStoreCache.shutDownInstance();
-            ThreadableCache.getInstance().clear();
             Services.setServiceLookup(null);
             if (secretService != null) {
                 secretService.close();
