@@ -50,7 +50,6 @@
 package com.openexchange.imap.threader.references;
 
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Comparator;
@@ -189,18 +188,21 @@ public final class Conversation {
                 return true;
             }
         }
+
+        String[] sReferences = this.referencesEmpty ? null : message.getReferences();
+        if (null != sReferences && containsAny(this.references, sReferences)) {
+            return true;
+        }
+
         if (!this.messageIdsEmpty) {
-            /*
-            if (this.messageIds.contains(message.getMessageId())) {
-                // Already contained
-                return false;
+            if (null == sReferences) {
+                sReferences = message.getReferences();
             }
-            */
-            final String[] sReferences = message.getReferences();
-            if (null != sReferences && containsAny(this.messageIds, Arrays.asList(sReferences))) {
+            if (null != sReferences && containsAny(this.messageIds, sReferences)) {
                 return true;
             }
         }
+
         return false;
     }
 
@@ -211,7 +213,19 @@ public final class Conversation {
      * @return <code>true</code> if references or referenced-by; otherwise <code>false</code>
      */
     public boolean referencesOrIsReferencedBy(final Conversation other) {
-        return (this.referencesEmpty ? false : containsAny(this.references, other.messageIds)) || (other.referencesEmpty ? false : containsAny(this.messageIds, other.references));
+        if (!this.referencesEmpty) {
+            if (containsAny(this.references, other.messageIds) || (other.referencesEmpty ? false : containsAny(this.references, other.references))) {
+                return true;
+            }
+        }
+
+        if (!other.referencesEmpty) {
+            if (containsAny(this.messageIds, other.references)) {
+                return true;
+            }
+        }
+
+        return false;
     }
 
     /**
@@ -221,7 +235,7 @@ public final class Conversation {
      * @return <code>true</code> if references; otherwise <code>false</code>
      */
     public boolean references(final Conversation other) {
-        return this.referencesEmpty ? false : containsAny(this.references, other.messageIds);
+        return this.referencesEmpty ? false : (containsAny(this.references, other.messageIds) || (other.referencesEmpty ? false : containsAny(this.references, other.references)));
     }
 
     /**
@@ -251,6 +265,22 @@ public final class Conversation {
         return false;
     }
 
+    /**
+     * Checks if at least one element is in both collections.
+     *
+     * @param set The first collection, must not be <code>null</code>
+     * @param arr The second collection, must not be <code>null</code>
+     * @return <code>true</code> if the intersection of the collections is non-empty
+     */
+    private static boolean containsAny(final Set<String> set, final String[] arr) {
+        for (int i = arr.length; i-- > 0;) {
+            if (set.contains(arr[i])) {
+                return true;
+            }
+        }
+        return false;
+    }
+
     /**
      *Adds the message identifiers from this conversation to given set.
      *
